# Release Notes
---

## [1.0.1](https://github.com/osl-incubator/containers-sugar/compare/1.0.0...1.0.1) (2023-01-21)


### Bug Fixes

* Fix quotes used by semantic release replace ([#8](https://github.com/osl-incubator/containers-sugar/issues/8)) ([66acb67](https://github.com/osl-incubator/containers-sugar/commit/66acb67b9275a2afea48b6dd97b143edfff80be1))
